@@ -303,23 +303,58 @@ class DAGSpec(MutableMapping):
     def from_directory(cls, path_to_dir):
         """Construct a DAGSpec from a directory
 
-        Looks for scripts (``.py``, ``.R`` or ``.ipynb``) in the directory and
-        interpret them as task sources, file names are assigned as task names
-        (without extension). The spec is generated with the default values in
-        the "meta" section.
+        Parameters
+        ----------
+        path_to_dir : str
+            The directory to use.  Looks for scripts
+            (``.py``, ``.R`` or ``.ipynb``) in the directory and interprets
+            them as task sources, file names are assigned as task names
+            (without extension). The spec is generated with the default values
+            in the "meta" section. Ignores files with invalid extensions.
 
         Notes
         -----
         ``env`` is not supported because the spec is generated from files
         in ``path_to_dir``, hence, there is no way to embed tags
         """
-        extensions = [
+        valid_extensions = [
             name for name, class_ in suffix2taskclass.items()
             if class_ is NotebookRunner
         ]
 
-        pattern = str(Path(path_to_dir, '*'))
-        files = chain.from_iterable(iglob(pattern + ext) for ext in extensions)
+        if Path(path_to_dir).is_dir():
+            pattern = str(Path(path_to_dir, '*'))
+            files = list(
+                chain.from_iterable(
+                    iglob(pattern + ext) for ext in valid_extensions))
+            return cls.from_files(files)
+        else:
+            raise NotADirectoryError(f'{path_to_dir!r} is not a directory')
+
+    @classmethod
+    def from_files(cls, files):
+        """Construct DAGSpec from list of files or glob-like pattern
+
+        Parameters
+        ----------
+        files : list or str
+            List of files to use or glob-like string pattern. If glob-like
+            pattern, ignores directories that match the criteria.
+        """
+        valid_extensions = [
+            name for name, class_ in suffix2taskclass.items()
+            if class_ is NotebookRunner
+        ]
+
+        if isinstance(files, str):
+            files = [f for f in iglob(files) if Path(f).is_file()]
+
+        invalid = [f for f in files if Path(f).suffix not in valid_extensions]
+
+        if invalid:
+            raise ValueError(f'Cannot instantiate DAGSpec from files with '
+                             f'invalid extensions: {invalid}. '
+                             f'Allowed extensions are: {valid_extensions}')
 
         tasks = [{
             'source': file_,
