@@ -52,7 +52,7 @@ TODO: describe BrokenProcesssPool status
 import abc
 import logging
 from datetime import datetime
-from ploomber.products import Product, MetaProduct
+from ploomber.products import Product, MetaProduct, EmptyProduct
 from ploomber.dag.DAG import DAG
 from ploomber.exceptions import TaskBuildError, DAGBuildEarlyStop
 from ploomber.tasks.TaskGroup import TaskGroup
@@ -310,14 +310,14 @@ class Task(abc.ABC):
                     'the task ran successfully but product '
                     '"{}" does not exist yet '
                     '(task.product.exists() returned False). '.format(
-                        self, self.product))
+                        self.name, self.product))
             else:
                 raise TaskBuildError(
                     'Error building task "{}": '
                     'the task ran successfully but at least one of the '
                     'products in "{}" does not exist yet '
                     '(task.product.exists() returned False). '.format(
-                        self, self.product))
+                        self.name, self.product))
 
     @property
     def on_failure(self):
@@ -596,7 +596,10 @@ class Task(abc.ABC):
                           'Task params: {}'.format(repr(self),
                                                    self.params)) from e
 
-        self.params._setitem('product', self.product)
+        # product does not becomes part of the task parameters when passing
+        # an EmptyProduct - this special kind of task is used by InMemoryDAG.
+        if not isinstance(self.product, EmptyProduct):
+            self.params._setitem('product', self.product)
 
         try:
             self.source.render(self.params)
@@ -715,7 +718,7 @@ class Task(abc.ABC):
             data['Product type'] = type(self.product).__name__
 
         if 'product' in sections:
-            data['Product'] = str(self.product)
+            data['Product'] = repr(self.product)
 
         if 'product_client' in sections:
             # FIXME: all products should have a client property
